@@ -1,4 +1,6 @@
 """Repos class"""
+from typing import Optional
+
 from seafileapi_extended.repo import Repo
 from seafileapi_extended.utils import raise_does_not_exist
 from urllib.parse import urlencode
@@ -22,18 +24,18 @@ class Repos(object):
             print(error, flush=True)
 
     @raise_does_not_exist("The requested library does not exist")
-    def get_repo(self, repo_id):
+    def get_repo(self, repo_id) -> Optional[Repo]:
         """Get the repo which has the id `repo_id`.
 
         Raises :exc:`DoesNotExist` if no such repo exists.
         """
 
         try:
-            response = self.client.get(f"/api2/repos/{repo_id}").json()
-            repo_json = response.json()
-            return Repo.from_json(self.client, repo_json)
+            response = self.client.get(f"/api2/repos/{repo_id}")
+            return Repo.from_json(self.client, response.json())
         except Exception as error:
             print(error, flush=True)
+            return None
 
     def list_repos(self, type=None):
         query = ""
